@@ -2,24 +2,29 @@
 # -*- coding: utf-8 -*-
 
 try:
+	chr = unichr
+	range = xrange
 	unicode__ = unicode
 	def unicode_(s):
 		try:
 			return unicode(s, 'utf8')
 		except TypeError:
 			return s
-except NameError:
-	unicode_, unicode__ = str, str
-
-try:
-	chr = unichr
+	def find_shared(keys1, keys2):
+		return {i for i in keys1 if i in keys2}
 except NameError:
 	chr = chr
+	range = range
+	unicode_, unicode__ = str, str
+	def find_shared(keys1, keys2):
+		return keys1 & keys2
 
 try:
-	range = xrange
-except NameError:
-	range = range
+	dict_keys = dict.iterkeys
+	dict_values = dict.itervalues
+except AttributeError:
+	dict_keys = dict.keys
+	dict_values = dict.values
 
 try:
 	import htmlentitydefs
